import { useReducer } from 'react';
function reducer(store, action) {
    try {
        const { type, payload } = action;
        switch (type) {
            case 'reset':
                return payload;
            case 'update':
                return { ...store, ...payload };
            default:
                throw new Error(`Invalid action: ${String(type)}`);
        }
    }
    catch (err) {
        console.error(err);
        const { message } = err;
        return { ...store, error: message };
    }
}
export function useStore(defaults) {
    const [store, dispatch] = useReducer((reducer), defaults);
    function reset(store) {
        const payload = { ...defaults, ...store };
        dispatch({ type: 'reset', payload });
    }
    function update(store) {
        dispatch({ type: 'update', payload: store });
    }
    return {
        reset,
        store,
        update
    };
}
//# sourceMappingURL=useStore.js.map