import { verifySignature, getEventHash } from 'nostr-tools';
import { now } from './util.js';
export class SignedEvent {
    _event;
    constructor(event) {
        this._event = event;
    }
    get data() {
        return this._event;
    }
    get isValid() {
        const hash = getEventHash(this.data);
        return hash === this.data.id && verifySignature(this.data);
    }
    get isExpired() {
        const { tags } = this.data;
        const tag = tags.find(e => e[0] === 'expiration');
        if (!Array.isArray(tag))
            return false;
        try {
            return parseInt(tag[1]) < now();
        }
        catch (err) {
            return true;
        }
    }
    isAuthor(pubkey) {
        return this.data.pubkey === pubkey;
    }
}
//# sourceMappingURL=event.js.map