import { Buff } from '@cmdcode/buff';
export function now() {
    return Math.floor(Date.now() / 1000);
}
export function isExpired(timestamp, timeout) {
    return now() > (timestamp + timeout);
}
export async function sleep(ms = 1000) {
    return new Promise(resolve => setTimeout(resolve, ms));
}
export async function withTimeout(fn, timeout = 5000) {
    let timer;
    return new Promise((resolve, reject) => {
        timer = setTimeout(() => { resolve(undefined); }, timeout);
        fn()
            .then((res) => { clearTimeout(timer); resolve(res); })
            .catch(err => { reject(err); });
    });
}
export function objFilter(obj, filter) {
    if (typeof obj === 'object' &&
        Array.isArray(filter)) {
        const entries = Object.entries(obj);
        const filtered = entries.filter(e => filter.includes(e[0]));
        return Object.fromEntries(filtered);
    }
    return obj;
}
export function tagHash(tag, bytes) {
    const hash = Buff.str(tag).digest;
    return Buff.join([hash, hash, ...bytes]);
}
//# sourceMappingURL=util.js.map